/***************************************************************************
 *   Copyright (C) 2010 - 2013 by Marcel Hasler                            *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of MPD Now Playing.                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include "configurationwidget.h"

ConfigurationWidget::ConfigurationWidget(QWidget *parent, Settings *settings)
    : QWidget(parent)
{
    m_settings = settings;

    m_ui.setupUi(this);

    m_ui.UseDefault->setChecked(m_settings->useDefault);
    if (m_settings->useDefault)
    {
        m_ui.Host->setText("localhost");
        m_ui.Host->setEnabled(false);

        m_ui.Port->setText(QString::number(6600));
        m_ui.Port->setEnabled(false);

        m_ui.Password->setText(QString());
        m_ui.Password->setEnabled(false);
    }
    else
    {
        m_ui.Host->setText(m_settings->host);
        m_ui.Host->setEnabled(true);

        m_ui.Port->setText(QString::number(m_settings->port));
        m_ui.Port->setEnabled(true);

        m_ui.Password->setText(m_settings->password);
        m_ui.Password->setEnabled(true);
    }

    connect(parent, SIGNAL(accepted()), this, SLOT(saveSettings()));
}


ConfigurationWidget::~ConfigurationWidget()
{
}


void ConfigurationWidget::saveSettings()
{
    m_settings->useDefault = m_ui.UseDefault->isChecked();
    if (m_settings->useDefault)
    {
        m_settings->host = QString("localhost");
        m_settings->port = 6600;
        m_settings->password = QString();
    }
    else
    {
        m_settings->host = m_ui.Host->text();
        m_settings->port = m_ui.Port->text().toInt();
        m_settings->password = m_ui.Password->text();
    }

    emit settingsChanged();
}
