/***************************************************************************
 *   Copyright (C) 2010 - 2013 by Marcel Hasler                            *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of MPD Now Playing.                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include "connectionthread.h"

ConnectionThread::ConnectionThread(const QString &host, unsigned int port, const QString &password)
    : QThread(),
      m_host(host),
      m_port(port),
      m_password(password)
{
}


ConnectionThread::~ConnectionThread()
{
}


void ConnectionThread::run()
{
    mpd_connection *connection = mpd_connection_new(m_host.toUtf8(), m_port, 0);

    mpd_error error = mpd_connection_get_error(connection);
    if (error == MPD_ERROR_SUCCESS)
    {
        if (!m_password.isEmpty())
            mpd_run_password(connection, m_password.toUtf8());

        // Test permission
        mpd_status *status = mpd_run_status(connection);
        if (status)
        {
            mpd_status_free(status);
            emit success(connection);
            return;
        }
    }

    // Something went wrong
    mpd_connection_free(connection);
    emit failed();
}
