/***************************************************************************
 *   Copyright (C) 2010 - 2013 by Marcel Hasler                            *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of MPD Now Playing.                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#ifndef MPDHANDLER_H
#define MPDHANDLER_H

#include "connectionthread.h"
#include "idlethread.h"

#include <mpd/client.h>

#include <QObject>
#include <QString>
#include <QTime>
#include <QTimer>

class MPDHandler : public QObject
{
    Q_OBJECT

public:
    enum MPDState
    {
        MPDStatePlay,
        MPDStatePause,
        MPDStateStop,
        MPDStateUnknown
    };

    MPDHandler();
    ~MPDHandler();

    void connect(const QString &host, unsigned int port, const QString &password = QString::null);
    void disconnect();

    MPDState state() const;

    const QString& artist() const;
    const QString& title() const;
    const QString& album() const;

    const QTime& elapsedTime() const;
    const QTime& totalTime() const;

public slots:
    void play();
    void stop();
    void prev();
    void next();

signals:
    void connectionSuccess();
    void connectionFailed();
    void connectionLost();

    void stateChanged();
    void timeChanged();

private:
    mpd_connection* connect() const;

    void updateState();
    void updateTime();

private slots:
    void slotConnectionSuccess(mpd_connection*);
    void slotConnectionFailed();
    void slotConnectionLost();

    void slotStateChanged();
    void slotTimeChanged();

private:
    ConnectionThread *m_connectionThread;
    IdleThread *m_idleThread;

    QTimer *m_updateTimeTimer;

    QString m_host;
    unsigned int m_port;
    QString m_password;

    MPDState m_state;

    QString m_artist;
    QString m_title;
    QString m_album;

    QTime m_elapsedTime;
    QTime m_totalTime;
};

#endif // MPDHANDLER_H
