/***************************************************************************
 *   Copyright (C) 2010 - 2013 by Marcel Hasler                            *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of MPD Now Playing.                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#ifndef MPDNOWPLAYING_H
#define MPDNOWPLAYING_H

#include "mpdhandler.h"
#include "settings.h"

#include <QGraphicsLinearLayout>
#include <QTimer>

#include <Plasma/Applet>
#include <Plasma/IconWidget>
#include <Plasma/Label>
#include <Plasma/Svg>

class MPDNowPlaying : public Plasma::Applet
{
    Q_OBJECT

public:
    MPDNowPlaying(QObject *parent, const QVariantList &args);
    ~MPDNowPlaying();

    void init();

protected:
    void createConfigurationInterface(KConfigDialog *parent);

private:
    void setUserInterfaceEnabled(bool enable);

private slots:
    void connect();

    void enableUserInterface();
    void disableUserInterface();

    void updateState();
    void updateTime();

    void updateText();
    void clearText();

    void saveConfiguration();
    void readConfiguration();

private:
    Plasma::Svg *m_svg;

    Plasma::Label *m_artistLabel;
    Plasma::Label *m_artistText;

    Plasma::Label *m_titleLabel;
    Plasma::Label *m_titleText;

    Plasma::Label *m_albumLabel;
    Plasma::Label *m_albumText;

    Plasma::Label *m_timeLabel;
    Plasma::Label *m_timeText;

    Plasma::IconWidget *m_playButton;
    Plasma::IconWidget *m_stopButton;
    Plasma::IconWidget *m_prevButton;
    Plasma::IconWidget *m_nextButton;

    QGraphicsLinearLayout *m_layout;

    QTimer *m_reconnectTimer;

    MPDHandler *m_mpdHandler;

    Settings m_settings;
};

#endif // MPDNOWPLAYING_H
